/*
 * EtherPix simulator
 *
 * Copyright 2017 Stefan Schuermans <stefan schuermans info>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef CONFIG_H
#define CONFIG_H

#include <string>
#include <vector>

/// config file
class Config
{
public:
  /**
   * @brief constructor
   * @param[in] configFile name of config file
   */
  Config(std::string const &configFile);

protected:
  /**
   * @brief remove whitespace at beging and end of string
   * @param[in,out] str string to process
   */
  static void trim(std::string &str);

  /**
   * @brief split string at sequences of whitespace
   * @param[in] str string to split
   * @param[out] fields fields of string
   */
  static void split(std::string const &str, std::vector<std::string> &fields);

  /**
   * @brief read config file
   * @param[in] configFile name of config file
   * @throws std::exception in case of error
   */
  void readFile(std::string const &configFile);

  /**
   * @brief process line from config file
   * @param[in] line line to process
   * @throws std::exception in case of error
   */
  void procLine(std::string line);

  /**
   * @brief process setting from config file
   * @param[in] setting name of the setting
   * @param[in] value value for setting
   * @throws std::exception in case of error
   */
  void procSetting(std::string const &setting, std::string const &value);

};

#endif // #ifndef CONFIG_H

